@@ -32,9 +32,10 @@ import json
 
 from bigml.api import FINISHED
 from bigml.api import (get_status, BigML, get_model_id,
-                       check_resource)
+                       check_resource, get_resource_type)
 from bigml.util import invert_dictionary, utf8
 from bigml.util import DEFAULT_LOCALE
+from bigml.modelfields import ModelFields
 
 # Query string to ask for fields: only the ones in the model, with summary
 # (needed for the list of terms in text fields) and
@@ -42,22 +43,25 @@ from bigml.util import DEFAULT_LOCALE
 ONLY_MODEL = 'only_model=true;limit=-1;'
 
 
-def retrieve_model(api, model_id, query_string=''):
-    """ Retrieves model info either from a local repo or from the remote server
+def retrieve_resource(api, resource_id, query_string=''):
+    """ Retrieves resource info either from a local repo or
+        from the remote server
 
     """
     if api.storage is not None:
         try:
-            with open("%s%s%s" % (api.storage, os.sep,
-                                  model_id.replace("/", "_"))) as model_file:
-                model = json.loads(model_file.read())
-            return model
+            stored_resource = "%s%s%s" % (api.storage, os.sep,
+                                          resource_id.replace("/", "_"))
+            with open(stored_resource) as resource_file:
+                resource = json.loads(resource_file.read())
+            return resource
         except ValueError:
             raise ValueError("The file %s contains no JSON")
         except IOError:
             pass
-    model = check_resource(model_id, api.get_model, query_string)
-    return model
+    api_getter = api.getters[get_resource_type(resource_id)]
+    resource = check_resource(resource_id, api_getter, query_string)
+    return resource
 
 
 def extract_objective(objective_field):
@@ -92,7 +96,7 @@ def check_model_structure(model):
              'model' in model))
 
 
-class BaseModel(object):
+class BaseModel(ModelFields):
     """ A lightweight wrapper of the basic model information
 
     Uses a BigML remote model to build a local version that contains the
@@ -115,8 +119,8 @@ class BaseModel(object):
                                                   resource_type='model',
                                                   method='get'))
             query_string = ONLY_MODEL
-            model = retrieve_model(api, self.resource_id,
-                                   query_string=query_string)
+            model = retrieve_resource(api, self.resource_id,
+                                      query_string=query_string)
             # Stored copies of the model structure might lack some necessary
             # keys
             if not check_model_structure(model):
@@ -145,10 +149,9 @@ class BaseModel(object):
                             fields[field]['summary'] = field_info['summary']
                         fields[field]['name'] = field_info['name']
                 objective_field = model['objective_fields']
-                self.objective_field = extract_objective(objective_field)
-                self.uniquify_varnames(fields)
-                self.inverted_fields = invert_dictionary(fields)
-                self.fields = fields
+                ModelFields.__init__(
+                    self, fields,
+                    objective_id=extract_objective(objective_field))
                 self.description = model['description']
                 self.field_importance = model['model'].get('importance',
                                                            None)
@@ -165,36 +168,6 @@ class BaseModel(object):
                             " find the 'model' key in the resource:\n\n%s" %
                             model)
 
-    def uniquify_varnames(self, fields):
-        """Tests if the fields names are unique. If they aren't, a
-           transformation is applied to ensure unicity.
-
-        """
-        unique_names = set([fields[key]['name'] for key in fields])
-        if len(unique_names) < len(fields):
-            self.transform_repeated_names(fields)
-
-    def transform_repeated_names(self, fields):
-        """If a field name is repeated, it will be transformed adding its
-           column number. If that combination is also a field name, the
-           field id will be added.
-
-        """
-        # The objective field treated first to avoid changing it.
-        unique_names = [fields[self.objective_field]['name']]
-
-        field_ids = [field_id for field_id in fields
-                     if field_id != self.objective_field]
-        for field_id in field_ids:
-            new_name = fields[field_id]['name']
-            if new_name in unique_names:
-                new_name = "{0}{1}".format(fields[field_id]['name'],
-                                           fields[field_id]['column_number'])
-                if new_name in unique_names:
-                    new_name = "{0}_{1}".format(new_name, field_id)
-                fields[field_id]['name'] = new_name
-            unique_names.append(new_name)
-
     def resource(self):
         """Returns the model resource ID
 
